<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome1Blog extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-blog-home-1';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'BLOG', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Blog widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post-list';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Blog widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-1' ];
	}

	public function get_keywords() {
		return [ 'blog' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
		$position_options = [
			''              => esc_html__('Default', 'bdevs-elementor'),
			'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
			'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
			'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
			'center'        => esc_html__('Center', 'bdevs-elementor') ,
			'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
			'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
			'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
			'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
			'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
		];

		return $position_options;
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Blog', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),
				'default'   => '3',
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_order',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'desc',
			]
		);

		$this->add_control(
			'button',
			[
				'label'       => __( ' Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('Button', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'link',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is Link Button', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	


		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->add_control(
			'show_subheading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display(); 
		extract($settings);	
		$post_number = $settings['post_number'];
		$order = $settings['post_order'];
		$wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => $order));

	    //other style
		$args = array('posts_per_page' => $post_number,'post_type' => 'post',  'orderby' => 'ID', 'order' => $order);	
		?>


		<!-- start recent-news-section -->
<section class="recent-news-section section-padding" id="news">
	<div class="container">
		<div class="row">
			<div class="col col-xs-12">
				<div class="section-title-s3">
					<span><?php print wp_kses_post($settings['subheading']); ?></span>
					<h2><?php print wp_kses_post($settings['heading']); ?></h2>
				</div>
			</div>
		</div>
		<div class="row">
			<div class="col col-xs-12">
				<div class="blog-grids">
					<?php
					$args = new \WP_Query(array(   
						'post_type' => 'post', 
					));  
					while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
						?>
						<div class="grid">
							<div class="entry-media">
								<?php $featured_image_3 = get_post_meta(get_the_ID(),'_cmb_featured_image_3', true); ?>

								<img src="<?php echo wp_get_attachment_url($featured_image_3);?>" alt>
							</div>
							<div class="entry-body">
								<span class="cat"><?php 
	                                    // Show all category for post
								$i = 1; foreach((get_the_category()) as $category) { 
									if ($i == 1){echo ''; }else {echo ' / ';}
									echo '<a class = "author-post section-14px-regular font-weight-500  title="'.$category->category_nicename . '" >'.$category->category_nicename . ' '.'</a>'; 
									$i++;
								} ?></span>
								<h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
								<p><?php if(isset($miex_redux_demo['blog_excerpt'])){?>

									<?php echo esc_attr(miex_excerpt($mecare_redux_demo['blog_excerpt'])); ?>

								<?php }else{?>

									<?php echo esc_attr(miex_excerpt(40)); ?>


									<?php } ?></p>
									<div class="read-more-date">
										<a href="<?php the_permalink(); ?>" class="read-more">
											<?php if(isset($miex_redux_demo['read_more'])){?>
												<?php echo wp_specialchars_decode(esc_attr($miex_redux_demo['read_more']));?>
												<?php }else{?><?php echo esc_html__( 'Read More ', 'miex' );  } ?></a>
												<span class="date"><?php the_time(get_option( 'date_format' ));?></span>
											</div>
										</div>
									</div>
									<?php			  
								endwhile; 
								wp_reset_postdata();
								?>
							</div>
						</div>
					</div>
					<div class="more-news">
						<a href="<?php print wp_kses_post($settings['link']); ?>" class="theme-btn-s2"><?php print wp_kses_post($settings['button']); ?></a>
					</div>
				</div> <!-- end container -->
			</section>
			<!-- end recent-news-section -->
<?php
}

}
