<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome1Testimonials extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-Testimonials-home-1';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'TESTIMONIALS HOME-1', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs About widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs About widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-1' ];
	}

	public function get_keywords() {
		return [ 'Testimonials' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
		$position_options = [
			''              => esc_html__('Default', 'bdevs-elementor'),
			'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
			'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
			'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
			'center'        => esc_html__('Center', 'bdevs-elementor') ,
			'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
			'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
			'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
			'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
			'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
		];

		return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_item',
			[
				'label' => esc_html__( 'Testimonials Items', 'bdevs-elementor' ),
			]
		);

			$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name'    => 'background',
						'label'   => esc_html__( 'Background', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
					],

					[
						'name'        => 'introduction',
						'label'       => esc_html__( 'Introduction', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is Introduction' , 'bdevs-elementor' ),
						'label_block' => true,
					],


					[
						'name'        => 'name',
						'label'       => esc_html__( 'Name', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is Name' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'position',
						'label'       => esc_html__( 'Position', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is Position' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					
					[
						'name'        => 'content',
						'label'       => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is Content' , 'bdevs-elementor' ),
						'label_block' => true,
					],
			
					[
						'name'        => 'stars_select',
						'label'     => esc_html__( 'Stars Select', 'bdevs-elementor' ),
						'type'      => Controls_Manager::SELECT,
						'dynamic' => [ 'active' => true ],
						'options'   => [
							'1'  => esc_html__( '1 Star', 'bdevs-elementor' ),
							'2'  => esc_html__( '2 Stars', 'bdevs-elementor' ),
							'3'  => esc_html__( '3 Stars', 'bdevs-elementor' ),
							'4'  => esc_html__( '4 Stars', 'bdevs-elementor' ),
							'5'  => esc_html__( '5 Stars', 'bdevs-elementor' ),
						],
						'default'   => '5',
					],

					
				],
			]
		);	
		$this->end_controls_section();	
		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings); ?>
		<!-- start testimonials-section -->
		<section class="testimonials-section section-padding">
			<div class="container">
				<div class="row">
					<div class="col col-xs-12">
						<div class="section-title-s3">
							<span><?php print wp_kses_post($settings['subheading']); ?></span>
							<h2><?php print wp_kses_post($settings['heading']); ?></h2>
						</div>
					</div>
				</div>
				<div class="row">
					<div class="col col-lg-10 col-lg-offset-1">
						<div class="testimonials-girds testimonials-slider">
							<?php foreach ( $settings['tabs'] as $item ):?>
								<div class="grid">
									<div class="img-holder">
										<img src="<?php print wp_kses_post($item['background']['url']); ?>" alt>
									</div>
									<div class="details">
										<h3><?php print wp_kses_post($item['introduction']); ?></h3>
										<p><?php print wp_kses_post($item['content']); ?></p>
										<div class="client-info">
											<h4><?php print wp_kses_post($item['name']); ?></h4>
											<span><?php print wp_kses_post($item['position']); ?></span>
										</div>
										<div class="rating">
											<?php if( wp_kses_post($item['stars_select']) == '1'): ?>
												<i class="fa fa-star"></i>
											<?php elseif( wp_kses_post($item['stars_select']) == '2'): ?>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>

											<?php elseif( wp_kses_post($item['stars_select']) == '3'): ?>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>

											<?php elseif( wp_kses_post($item['stars_select']) == '4'): ?>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>
											<?php elseif( wp_kses_post($item['stars_select']) == '5'):?>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>
												<i class="fa fa-star"></i>
										 <?php endif; ?> 
									</div>
								</div>
							</div>
						<?php endforeach;?>
					</div>
				</div>
			</div> <!-- end container -->
		</section>
		<!-- end testimonials-section -->
		<?php
	}

}