<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome2Portfolio extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-portfolio-home-2';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'PORTFOLIO HOME-2', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-2' ];
	}

	public function get_keywords() {
		return [ 'portfolio' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
		$position_options = [
			''              => esc_html__('Default', 'bdevs-elementor'),
			'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
			'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
			'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
			'center'        => esc_html__('Center', 'bdevs-elementor') ,
			'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
			'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
			'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
			'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
			'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
		];

		return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Portfolio', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'background_image',
			[
				'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
			]
		);	

		$this->add_control(
			'subheading',
			[
				'label'       => __( 'Subheading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is subheading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		

		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your count', 'bdevs-elementor' ),
				'default'   => '3',
				'label_block' => true,
			]
		);

		$this->add_control(
			'post_order',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'desc',
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);

		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display(); 
		extract($settings);	
		$post_number = $settings['post_number'];
		$order = $settings['post_order'];
		$wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'portfolio',  'orderby' => 'ID', 'order' => $order));

	    //other style
		$args = array('posts_per_page' => $post_number,'post_type' => 'portfolio',  'orderby' => 'ID', 'order' => $order);	
		?>


		<!-- start portfolio-section-s2 -->
		<section class="portfolio-section-s2 section-padding" id="portfolio">
			<style type="text/css">
				.portfolio-section-s2:before {
				content: "";
				background: url(<?php print wp_kses_post($settings['background_image']['url']); ?>) center center/cover no-repeat local;
				width: 1654px;
				height: 930px;
				position: absolute;
				left: 50%;
				top: 0;
				-webkit-transform: translateX(-50%);
				-moz-transform: translateX(-50%);
				-o-transform: translateX(-50%);
				-ms-transform: translateX(-50%);
				transform: translateX(-50%);
				}
			</style>
			<div class="vertical-heading-s2">
				<span>our portfolio</span>
			</div>

			<div class="container">
				<div class="row">
					<div class="col col-lg-6 col-lg-offset-3 col-md-8 col-md-offset-2">
						<div class="section-title-s5">
							<h2><?php print wp_kses_post($settings['heading']); ?></h2>
							<p><?php print wp_kses_post($settings['subheading']); ?></p>
						</div>
					</div>
				</div>

				<div class="row">
					<div class="col col-xs-12">
						<div class="sortable-gallery">
							<div class="gallery-filters portfolio-list">
								<ul>
									<li>
										<a data-filter="*" href="#" class="current"><?php echo esc_html__( 'All', 'miex' );?></a>
									<?php 

                            $categories = get_terms('type1');   

                             foreach( (array)$categories as $categorie){

                                $cat_name = $categorie->name;

                                $cat_slug = $categorie->slug;

                        ?>
                                    <li>
                                        <a data-filter=".<?php echo esc_attr($cat_slug);?>" href="#"><?php echo esc_attr($cat_name);?></a>                                        
                                    </li>
                                <?php } ?>
								</ul>
							</div>
							<div class="gallery-container portfolio-grids">
											<?php
					                $args = new \WP_Query(array(   
					                            'post_type' => 'portfolio', 
					                        ));  
					                while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
					                $cates = get_the_terms(get_the_ID(),'type1');

					                    $cate_name ='';

					                    $cate_slug = '';

					                    foreach((array)$cates as $cate){

					                        $cate_name .= $cate->name.'  ' ;

					                        $cate_slug .= $cate->slug .' '; 

					                } 

					                $categs = get_the_terms(get_the_ID(),'category1');

					                    $categ_name ='';

					                    foreach((array)$categs as $categ){

					                        $categ_name .= $categ->name.'  ' ;

					                } 
					            ?>
								<div class="grid-item <?php echo esc_attr($cate_slug);?>">
									<div class="inner">
										<div class="img-holder">
											<img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt>
										</div>
										<div class="details">
											<h3><?php the_title(); ?></h3>
											<span class="cat"><?php echo esc_attr($categ_name);?></span>
											<a href="<?php the_permalink(); ?>" class="view-project"><?php if(isset($miex_redux_demo['view'])){?>
												<?php echo wp_specialchars_decode(esc_attr($miex_redux_demo['view']));?>
												<?php }else{?><?php echo esc_html__( ' View Project ', 'miex' );  } ?></a>
										</div>
									</div>
								</div>
 						<?php   
				        endwhile; 
				        wp_reset_postdata(); ?>
							</div>
						</div>
					</div>
				</div> <!-- end container -->
			</section>
		<!-- end portfolio-section-s2 -->
		<?php
	}

}