<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome3Slider extends \Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Elementor widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'bdevs-slider-home-3';
    }

    /**
     * Get widget title.
     *
     * Retrieve Bdevs Elementor widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'SLIDER HOME-3', 'bdevs-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve Bdevs Slider widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-slides';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Bdevs Slider widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'home-3' ];
    }

    public function get_keywords() {
        return [ 'slider' ];
    }

    public function get_script_depends() {
        return [ 'bdevs-elementor'];
    }

    // BDT Position
    protected function element_pack_position() {
        $position_options = [
            ''              => esc_html__('Default', 'bdevs-elementor'),
            'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
            'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
            'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
            'center'        => esc_html__('Center', 'bdevs-elementor') ,
            'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
            'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
            'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
            'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
            'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
        ];

        return $position_options;
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_heading',
            [
                'label' => esc_html__( 'Slider', 'bdevs-elementor' ),
            ]
        );

     $this->add_control(
            'background_image',
            [
                'label'   => esc_html__( 'Background Image', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        ); 

         $this->add_control(
            'background',
            [
                'label'   => esc_html__( 'Featured Image', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        ); 
            
        $this->add_control(
            'heading',
            [
                'label'       => __( 'Heading', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXTAREA,
                'default'       => __('This is heading', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

        $this->add_control(
            'content',
            [
                'label'       => __( 'Content', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('This is Content', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

            $this->add_control(
            'image_1',
            [
                'label'   => esc_html__( 'Image 1', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );

             $this->add_control(
            'link_1',
            [
                'label'       => __( 'Link 1', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('Link Image 1', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

           $this->add_control(
            'image_2',
            [
                'label'   => esc_html__( 'Image 2', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );  
            $this->add_control(
            'link_2',
            [
                'label'       => __( 'Link 2', 'bdevs-elementor' ),
                'type'        => Controls_Manager::TEXT,
                'default'       => __('Link Image 2', 'bdevs-elementor'),
                'label_block' => true,
            ]
        );  

          
        $this->end_controls_section();


        $this->start_controls_section(
            'section_content_layout',
            [
                'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
                        'icon'  => 'fa fa-align-justify',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'description'  => 'Use align to match position',
                'default'      => 'left',
            ]
        );

        $this->add_control(
            'show_subheading',
            [
                'label'   => esc_html__( 'Show Subheading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_heading',
            [
                'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );  

        $this->end_controls_section();

    }

    public function render() {

        $settings  = $this->get_settings_for_display();
        extract($settings);
        ?>   
        <!-- start hero-section -->
        <section class="hero-section-s3">
            <style type="text/css">
            .hero-section-s3:before {
            content: "";
            background: url(<?php print wp_kses_post($settings['background_image']['url']); ?>) right center/100% no-repeat local;
            width: 80%;
            height: 100%;
            position: absolute;
            right: 0;
            top: 0;
            z-index: 1;
            }
                
            </style>
            <div class="container">
                <div class="row">
                    <div class="col col-md-6 col-sm-8">
                        <div class="content">
                            <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                            <p><?php print wp_kses_post($settings['content']); ?></p>
                            <div class="btns">
                                <a href="<?php print wp_kses_post($settings['link_1']); ?>"><img src="<?php print wp_kses_post($settings['image_1']['url']); ?>" alt></a>
                                <a href="<?php print wp_kses_post($settings['link_2']); ?>"><img src="<?php print wp_kses_post($settings['image_2']['url']); ?>" alt></a>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="phone">
                    <img src="<?php print wp_kses_post($settings['background']['url']); ?>" alt>
                </div>
            </div>
        </section>
        <!-- end hero-section -->
    <?php
    }

}