<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome4About extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-about-home-4';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'ABOUT HOME-4','bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs About widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs About widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-4' ];
	}

	public function get_keywords() {
		return [ 'about' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'About', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'default'		=> __('Content', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		 $this->add_control(
            'background',
            [
                'label'   => esc_html__( 'Featured Image', 'bdevs-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [ 'active' => true ],
                'description' => esc_html__( 'Add image from here', 'bdevs-elementor' ),
            ]
        );

	$this->end_controls_section();


		$this->start_controls_section(
			'section_content_items',
			[
				'label' => esc_html__( 'About Skill Items', 'bdevs-elementor' ),
			]	
		);


		 $this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [

					[
						'name'        => 'title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'percent',
						'label'       => esc_html__( 'Percent', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Percent' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				]
			]
		);


		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_items2',
			[
				'label' => esc_html__( 'About Items', 'bdevs-elementor' ),
			]	
		);
		 $this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [

					[
						'name'        => 'icon',
						'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Icon' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'heading_2',
						'label'       => esc_html__( 'Heading 2', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Heading 2' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'description',
						'label'       => esc_html__( 'Description', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Description' , 'bdevs-elementor' ),
						'label_block' => true,
					],



				]
			]
		);

		$this->end_controls_section();




		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings); ?>
		   <!-- start about-section-s5 -->
        <section class="about-section-s5 section-padding" id="about">
            <div class="container">
                <div class="row">
                    <div class="col-md-6">
                        <div class="section-title-s9">
                            <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                        </div>
                        <div class="about-text">
                            <p><?php print wp_kses_post($settings['content']); ?></p>
                        </div>
                        <div class="signature">
                            <img src="<?php print wp_kses_post($settings['background']['url']); ?>" alt>
                        </div>
                    </div>
                    <div class="col col-md-6">
                        <div class="skills">
                        	<?php foreach ( $settings['tabs'] as $item ):?>
                            <div class="skill">
                                <h6><?php print wp_kses_post($item['title']); ?></h6>
                                <div class="progress">
                                    <div class="progress-bar" data-percent="<?php print wp_kses_post($item['percent']); ?>"></div>
                                </div>
                            </div>
                             <?php endforeach;?>  
                        </div>                        
                    </div>
                </div>
                <div class="row">
                    <div class="col col-xs-12">
                        <div class="features-grids">
                        <?php foreach ( $settings['tabs2'] as $item ):?>
                            <div class="grid">
                                <div class="icon">
                                    <i class="<?php print wp_kses_post($item['icon']); ?>"></i>
                                </div>
                                <div class="details">
                                    <h3><?php print wp_kses_post($item['heading_2']); ?></h3>
                                    <p><?php print wp_kses_post($item['description']); ?></p>
                                </div>
                            </div>
                            <?php endforeach;?>  
                        </div>
                    </div>
                </div>                
            </div> <!-- end container -->
        </section>
        <!-- end about-section-s5 -->
	<?php
	}
}