<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Bdevshome4Experience extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-Experience-home-4';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Experience HOME-4','bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs About widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs About widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'home-4' ];
	}

	public function get_keywords() {
		return [ 'Experience' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Experience', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'		=> __('This is Heading', 'bdevs-elementor'),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [	
					
					[
						'name'        => 'position',
						'label'       => esc_html__( ' Position', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'This is Position' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'work',
						'label'       => esc_html__( ' Work', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Work' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'experience',
						'label'       => esc_html__( ' Experience', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Experience' , 'bdevs-elementor' ),
						'label_block' => true,
					],

				],
			]
		);

	$this->end_controls_section();
		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'left',
			]
		);
		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings); ?>


	  <!-- start experience-section -->
        <section class="experience-section section-padding" id="experience">
            <div class="container">
                <div class="row">
                    <div class="col col-xs-12">
                        <div class="section-title-s10">
                            <h2><?php print wp_kses_post($settings['heading']); ?></h2>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col col-xs12">
                    	<?php $i=0;
                	foreach ( $settings ['tabs'] as $item ):
                	$i++; ?>
                        <div class="experience-grids">     	
                	<?php if($i % 3 == 1){ ?>
                            <div class="grid">
                                <div class="jobtitle">
                                    <h4><?php print wp_kses_post($item['position']); ?></h4>
                                    <span><?php print wp_kses_post($item['work']); ?></span>
                                </div>
                                <div class="job-duration">
                                    <h4><?php print wp_kses_post($item['experience']); ?></h4>
                                </div>
                            </div>
                       <?php }elseif($i % 3 == 2){ ?>
                            <div class="grid grid-s2">
                                <div class="job-duration">
                                    <h4><?php print wp_kses_post($item['experience']); ?></h4>
                                </div>
                                <div class="jobtitle">
                                    <h4><?php print wp_kses_post($item['position']); ?></h4>
                                    <span><?php print wp_kses_post($item['work']); ?></span>
                                </div>
                            </div>
                       <?php }else{ ?>
                            <div class="grid">
                                <div class="jobtitle">
                                    <h4><?php print wp_kses_post($item['position']); ?></h4>
                                    <span><?php print wp_kses_post($item['work']); ?></span>
                                </div>
                                <div class="job-duration">
                                    <h4><?php print wp_kses_post($item['experience']); ?></h4>
                                </div>
                            </div>
                            <?php } ?>
                        </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div> <!-- end container -->
            <div class="pencil-box">
                <img src="assets/images/pencil-box.png" alt>
            </div>
        </section>
        <!-- end experience-section -->
	<?php
	}
}